==> Smdn.Net.Pop3.Client-0.22.tar.bz2: Smdn.Net.Pop3.Client-0.22/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client.Transaction/PopTransactionResult.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Pop3.Protocol.Client;

namespace Smdn.Net.Pop3.Client.Transaction {
  public class PopTransactionResult<TResultValue> : PopTransactionResult where TResultValue : class {
    public TResultValue Value {
      get { return val; }
    }

    public PopTransactionResult()
      : base()
    {
      this.val = null;
    }

    public PopTransactionResult(PopTransactionResultCode code, TResultValue val, string description)
      : base(code, description)
    {
      // allow null
      this.val = val;
    }

    public PopTransactionResult(TResultValue val, string description)
      : base(PopTransactionResultCode.Ok, description)
    {
      if (val == null)
        throw new ArgumentNullException("val");

      this.val = val;
    }

    private /*readonly*/ TResultValue val;
  }

  public class PopTransactionResult {
    public PopTransactionResultCode Code {
      get { return code; }
      internal set { code = value; }
    }

    public bool Succeeded {
      // true for 2xx, false for 3xx/4xx/5xx
      get { return ((int)code < 300); }
    }

    public bool Failed {
      get { return !Succeeded; }
    }

    public Exception Exception {
      get { return exception; }
      internal set { exception = value; }
    }

    public string Description {
      get { return description; }
      internal set { description = value; }
    }

    public virtual IEnumerable<PopResponse> ReceivedResponses {
      get { return receivedResponses; }
      protected internal set
      {
        if (value == null)
          throw new ArgumentNullException();
        receivedResponses = value;
      }
    }

    public PopTransactionResult()
      : this(PopTransactionResultCode.Default, string.Empty)
    {
    }

    public PopTransactionResult(PopTransactionResultCode code, string description)
    {
      this.code = code;
      this.description = description;
    }

    /*
    public PopStatusResponse GetResponseCode(PopResponseCode code)
    {
      foreach (var resp in receivedResponses) {
        if (resp is PopStatusResponse && (resp as PopStatusResponse).ResponseText.Code == code)
          return (resp as PopStatusResponse);
      }

      return null;
    }
    */

    public static explicit operator bool(PopTransactionResult r)
    {
      return r.Succeeded;
    }

    public override string ToString()
    {
      return string.Format("{{Succeeded={0} Code={1} Description={2}}}", Succeeded, code, description);
    }

    private PopTransactionResultCode code;
    private Exception exception;
    private string description;
    private IEnumerable<PopResponse> receivedResponses = new PopResponse[] {};
  }
}

==> Smdn.Net.Pop3.Client-0.28.tar.bz2: Smdn.Net.Pop3.Client-0.28/Smdn.Net.Pop3.Client/Smdn.Net.Pop3.Client.Transaction/PopTransactionResult.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Collections.Generic;

using Smdn.Net.Pop3.Protocol;
using Smdn.Net.Pop3.Protocol.Client;

namespace Smdn.Net.Pop3.Client.Transaction {
  public class PopTransactionResult<TResultValue> : PopTransactionResult where TResultValue : class {
    public TResultValue Value {
      get { return val; }
    }

    public PopTransactionResult()
      : base()
    {
      this.val = null;
    }

    public PopTransactionResult(TResultValue val, PopResponseText responseText)
      : base(PopTransactionResultCode.Ok, responseText)
    {
      if (val == null)
        throw new ArgumentNullException("val");

      this.val = val;
    }

    private /*readonly*/ TResultValue val;
  }

  public class PopTransactionResult {
    public PopTransactionResultCode Code {
      get { return code; }
      internal set { code = value; }
    }

    public bool Succeeded {
      // true for 2xx, false for 3xx/4xx/5xx
      get { return ((int)code < 300); }
    }

    public bool Failed {
      get { return !Succeeded; }
    }

    public Exception Exception {
      get { return exception; }
      internal set { exception = value; }
    }

    public string Description {
      get { return description; }
      internal set { description = value; }
    }

    public string ResponseText {
      get { return responseText; }
      internal set { responseText = value; }
    }

    public PopStatusResponse StatusResponse {
      get { return statusResponse; }
      internal set { statusResponse = value; }
    }

    public string ResultText {
      get
      {
        if (responseText == null)
          return string.Format("<{0}>", description);
        else
          return string.Format("\"{0}\"", responseText);
      }
    }

    public virtual IEnumerable<PopResponse> ReceivedResponses {
      get { return receivedResponses; }
      protected internal set
      {
        if (value == null)
          throw new ArgumentNullException();
        receivedResponses = value;
      }
    }

    public PopTransactionResult()
      : this(PopTransactionResultCode.Default, null, null)
    {
    }

    public PopTransactionResult(PopTransactionResultCode code, string description)
      : this(code, description, null)
    {
    }

    public PopTransactionResult(PopTransactionResultCode code, PopResponseText responseText)
      : this(code, null, responseText.Text.ToString())
    {
    }

    private PopTransactionResult(PopTransactionResultCode code, string description, string responseText)
    {
      this.code = code;
      this.description = description;
      this.responseText = responseText;
    }

    public PopStatusResponse GetResponseCode(PopResponseCode code)
    {
      foreach (var resp in receivedResponses) {
        if (resp is PopStatusResponse && (resp as PopStatusResponse).ResponseText.Code == code)
          return (resp as PopStatusResponse);
      }

      return null;
    }

    public static explicit operator bool(PopTransactionResult r)
    {
      return r.Succeeded;
    }

    public override string ToString()
    {
      return string.Format("{{Succeeded={0} Code={1} Description='{2}' ResponseText='{3}'}}",
                           Succeeded,
                           code,
                           description,
                           responseText);
    }

    private PopTransactionResultCode code;
    private Exception exception;
    private string description;
    private string responseText;
    private PopStatusResponse statusResponse = null;
    private IEnumerable<PopResponse> receivedResponses = new PopResponse[] {};
  }
}
